==> chromium_108.0.5359.124.orig.tar.xz: chromium-108.0.5359.124/ash/webui/projector_app/test/mock_xhr_sender.h <==
// Copyright 2022 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_WEBUI_PROJECTOR_APP_TEST_MOCK_XHR_SENDER_H_
#define ASH_WEBUI_PROJECTOR_APP_TEST_MOCK_XHR_SENDER_H_

#include <string>

#include "ash/webui/projector_app/projector_xhr_sender.h"
#include "base/callback.h"

namespace network::mojom {
class URLLoaderFactory;
}  // namespace network::mojom

class GURL;

namespace ash {

// A mock class of ProjectorXhrSender which helps to verify that the update
// indexable text request is sent correctly.
class MockXhrSender : public ProjectorXhrSender {
 public:
  using OnSendCallback = base::OnceCallback<
      void(const GURL&, const std::string&, const std::string&)>;

  MockXhrSender(OnSendCallback quit_closure,
                network::mojom::URLLoaderFactory* url_loader_factory);
  MockXhrSender(const MockXhrSender&) = delete;
  MockXhrSender& operator=(const MockXhrSender&) = delete;
  ~MockXhrSender() override;

  // ProjectorXhrSender:
  void Send(const GURL& url,
            const std::string& method,
            const std::string& request_body,
            bool use_credentials,
            bool use_api_key,
            SendRequestCallback callback,
            const base::Value::Dict& headers,
            const std::string& account_email) override;

 private:
  // Quits the current run loop. Used to verify the MockXhrSender::Send getting
  // called.
  OnSendCallback quit_closure_;
};

}  // namespace ash

#endif  // ASH_WEBUI_PROJECTOR_APP_TEST_MOCK_XHR_SENDER_H_

==> chromium_111.0.5563.64.orig.tar.xz: chromium-111.0.5563.64/ash/webui/projector_app/test/mock_xhr_sender.h <==
// Copyright 2022 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_WEBUI_PROJECTOR_APP_TEST_MOCK_XHR_SENDER_H_
#define ASH_WEBUI_PROJECTOR_APP_TEST_MOCK_XHR_SENDER_H_

#include <string>

#include "ash/webui/projector_app/projector_xhr_sender.h"
#include "base/functional/callback.h"

namespace network::mojom {
class URLLoaderFactory;
}  // namespace network::mojom

class GURL;

namespace ash {

// A mock class of ProjectorXhrSender which helps to verify that the update
// indexable text request is sent correctly.
class MockXhrSender : public ProjectorXhrSender {
 public:
  using OnSendCallback = base::OnceCallback<
      void(const GURL&, const std::string&, const std::string&)>;

  MockXhrSender(OnSendCallback quit_closure,
                network::mojom::URLLoaderFactory* url_loader_factory);
  MockXhrSender(const MockXhrSender&) = delete;
  MockXhrSender& operator=(const MockXhrSender&) = delete;
  ~MockXhrSender() override;

  // ProjectorXhrSender:
  void Send(const GURL& url,
            const std::string& method,
            const std::string& request_body,
            bool use_credentials,
            bool use_api_key,
            SendRequestCallback callback,
            const base::Value::Dict& headers,
            const std::string& account_email) override;

 private:
  // Quits the current run loop. Used to verify the MockXhrSender::Send getting
  // called.
  OnSendCallback quit_closure_;
};

}  // namespace ash

#endif  // ASH_WEBUI_PROJECTOR_APP_TEST_MOCK_XHR_SENDER_H_
